
% the probability that the number of nuclear cells on the x axis (in the 
% range 1 to n) receives contact from 1 or more, 2 or more, or 3 or more
% active Purkinje cells out of m, with divergence of 1:z.

% variables

m = 5;
n = 50;
x = [0:1:n];
z = 25;

% the probability a given nuclear cell (out of 50) receives contact from
% 0, 1, 2 or 3 out of m active PCs

Fx = factorial(n)./(factorial(x).*factorial(n-x));
Fm1 = factorial(m)./(factorial(1).*factorial(m-1));
Fm2 = factorial(m)./(factorial(2).*factorial(m-2));
Fm3 = factorial(m)./(factorial(3).*factorial(m-3));
p0 = (1-(z/n))^m;
p1 = (z/n)*((1-(z/n))^(m-1))*Fm1;
p2 = ((z/n)^2)*((1-(z/n))^(m-2))*Fm2;
p3 = ((z/n)^3)*((1-(z/n))^(m-3))*Fm3;

% the probability that x out of n nuclear cells receives contact from 
% 1, 2 or 3 out of m active PCs (not graphed)

P1 = (p1.^x).*((1-p1).^(n-x)).*Fx;
P2 = (p2.^x).*((1-p2).^(n-x)).*Fx;
P3 = (p3.^x).*((1-p3).^(n-x)).*Fx;

% the probability that x out of n nuclear cells receives contact from
% 1 or more, 2 or more, or 3 or more (out of m) active PCs

P1up = ((1-p0).^x).*(p0.^(n-x)).*Fx;
P2up = ((1-p0-p1).^x).*((p0+p1).^(n-x)).*Fx;
P3up = ((1-p0-p1-p2).^x).*((p0+p1+p2).^(n-x)).*Fx;

% create graph, old fig
% plot(y,P1,'k:',y,P2,'g:',y,P3,'b:',y,P1up,y,P2up,y,P3up),xlabel('Nuclear cells'), ...
%     ylabel('Probability'),title('20 active PCs')

% create graph
plot(x,P1up,'b',x,P2up,'b',x,P3up,'b'),xlabel('Nuclear cells'), ...
    ylabel('Probability'),title('10 active PCs')