
% PANEL A

% THE PROBABILITY THAT THE NUMBER OF NUCLEAR CELLS ON THE x AXIS (IN THE
% RANGE 1 TO n) RECEIVES CONTACT FROM 1 OR MORE OR 2 OR MORE PURKINJE CELLS
% OUT OF A RANDOM SAMPLE OF m, WITH DIVERGENCE OF 1:z.

opengl software
figure;

% subplot(2,24,[1 2 3 4 5 6 7 8 9 10 11])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%subplot(7,24,[1 2 3 4 5 6 7 8 9 10 11 25 26 27 28 29 30 31 32 33 34 35])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% variables

m = 10; n = 50; x = [0:1:n]; z = 5;

% the probability a given nuclear cell (out of 50) receives contact from
% 0, 1, 2 or 3 out of m active PCs

Fx = factorial(n)./(factorial(x).*factorial(n-x));
Fm1 = factorial(m)./(factorial(1).*factorial(m-1));
Fm2 = factorial(m)./(factorial(2).*factorial(m-2));
Fm3 = factorial(m)./(factorial(3).*factorial(m-3));
p0 = (1-(z/n))^m;
p1 = (z/n)*((1-(z/n))^(m-1))*Fm1;
p2 = ((z/n)^2)*((1-(z/n))^(m-2))*Fm2;
p3 = ((z/n)^3)*((1-(z/n))^(m-3))*Fm3;

% the probability that x out of n nuclear cells receives contact from 
% 1, 2 or 3 out of m active PCs (not graphed)

P1 = (p1.^x).*((1-p1).^(n-x)).*Fx;
P2 = (p2.^x).*((1-p2).^(n-x)).*Fx;
P3 = (p3.^x).*((1-p3).^(n-x)).*Fx;

% the probability that x out of n nuclear cells receives contact from
% 1 or more, 2 or more, or 3 or more (out of m) active PCs

P1up = ((1-p0).^x).*(p0.^(n-x)).*Fx;
P2up = ((1-p0-p1).^x).*((p0+p1).^(n-x)).*Fx;
P3up = ((1-p0-p1-p2).^x).*((p0+p1+p2).^(n-x)).*Fx;

% Plot
subplot(2,2,1)
plot(x,P1up,'-o','MarkerSize',2.5,'color',[1 .75 .75],'MarkerFaceColor',[1 .75 .75])
xlabel('nuclear cells'); ylabel('p'); title('Monosynaptic divergence')
xlim([0 50]); ylim([0 0.35])
yticks([0 0.1 0.2 0.3])
set(gca,'FontSize',10)
hold on
plot(x,P2up,'-o','MarkerSize',2.5,'color',[.8 .45 .45],'MarkerFaceColor',[.7 .45 .45])
plot(x,P3up,'-o','MarkerSize',2.5,'color',[.5 .1 .1],'MarkerFaceColor',[.5 .1 .1])

% plot(x,P1up,'.','MarkerSize',2.2,'LineWidth',0.8)
% xlabel('nuclear cells');ylabel('prob');title('PC-DCN');xlim([0 50]);ylim([0 0.35]);
% hold on
% plot(x,P2up,'.','MarkerSize',2.2,'LineWidth',0.8)
% plot(x,P3up,'.','MarkerSize',2.2,'LineWidth',0.8)

% PANEL B

% THE SAME AS PANEL A BUT WITH HIGHER DIVERGENCE - 1:25, TO ILLUSTRATE 
% BISYNAPTIC DIVERGENCE, DERIVED FROM DIVERGENCE OF 1:5 AT EACH STEP - AND
% INCLUDING DATA FOR NUCLEAR CELLS RECEIVING AN EFFECT FROM AT LEAST 3 
% PURKINJE CELLS

% subplot(2,24,[14 15 16 17 18 19 20 21 22 23 24])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% subplot(7,24,[14 15 16 17 18 19 20 21 22 23 24 38 39 40 41 42 43 44 45 46 47 48])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% variables

m = 33; n = 50; x = [0:1:n]; z = 5;

% the probability a given nuclear cell (out of 50) receives contact from
% 0, 1, 2 or 3 out of m active PCs

Fx = factorial(n)./(factorial(x).*factorial(n-x));
Fm1 = factorial(m)./(factorial(1).*factorial(m-1));
Fm2 = factorial(m)./(factorial(2).*factorial(m-2));
Fm3 = factorial(m)./(factorial(3).*factorial(m-3));
p0 = (1-(z/n))^m;
p1 = (z/n)*((1-(z/n))^(m-1))*Fm1;
p2 = ((z/n)^2)*((1-(z/n))^(m-2))*Fm2;
p3 = ((z/n)^3)*((1-(z/n))^(m-3))*Fm3;

% the probability that x out of n nuclear cells receives contact from 
% 1, 2 or 3 out of m active PCs (not graphed)

P1 = (p1.^x).*((1-p1).^(n-x)).*Fx;
P2 = (p2.^x).*((1-p2).^(n-x)).*Fx;
P3 = (p3.^x).*((1-p3).^(n-x)).*Fx;

% the probability that x out of n nuclear cells receives contact from
% 1 or more, 2 or more, or 3 or more (out of m) active PCs

P1up = ((1-p0).^x).*(p0.^(n-x)).*Fx;
P2up = ((1-p0-p1).^x).*((p0+p1).^(n-x)).*Fx;
P3up = ((1-p0-p1-p2).^x).*((p0+p1+p2).^(n-x)).*Fx;

% Plot

subplot(2,2,2)
plot(x,P1up,'-o','MarkerSize',2.5,'color',[.9 .65 .65],'MarkerFaceColor',[.9 .65 .65])
xlabel('nuclear cells'); ylabel('P'); title('Disynaptic divergence')
xlim([0 50]); ylim([0 0.35])
yticks([0 0.1 0.2 0.3])
set(gca,'FontSize',10)
hold on
plot(x,P2up,'-o','MarkerSize',2.5,'color',[.7 .45 .45],'MarkerFaceColor',[.7 .45 .45])
plot(x,P3up,'-o','MarkerSize',2.5,'color',[.5 .25 .25],'MarkerFaceColor',[.5 .25 .25])

% stem(x,P1up,'o','filled','MarkerSize',2.2,'LineWidth',0.8)
% xlabel('nuclear cells');title('Nucleo-nuclear');xlim([0 50]);ylim([0 0.35])
% hold on
% stem(x,P2up,'o','filled','MarkerSize',2.2,'LineWidth',0.8)
% stem(x,P3up,'o','filled','MarkerSize',2.2,'LineWidth',0.8)


% %CODING AT NUCLAR GROUP LEVEL
% 
% % opengl software
% % figure;
% 
% %PANEL C
% 
% %THE NUMBER OF PC SPIKES RECEIVED BY A NUCLEAR CELL IN 1 ms, WITH AND 
% %WITHOUT (5 ms) INTEGRATION, AT AN EXTRAPOLATED PC RATE OF 147.5 Hz. EVEN 
% %WITHOUT INTEGRATION, THE NUMBER IS IN A MODEST AND RELIABLE RANGE. WITH
% %INTEGRATION THE RANGE IS NARROWER AND TENDS TO A RECOGNISABLY NORMAL
% %DISTRIBUTION. THE PC RATE IS SELECTED BECAUSE IT IS IN THE 
% %PHYSIOLOGICAL RANGE AND OTHERWISE AT RANDOM. 
% 
% i=1;
% el5s=[];
% integ_el5s=[];
% 
% while i<51
%     j=1;
%     summed=zeros([1 200]);
%     while j<41
%         PC=array();
%         summed=(summed+PC);
%         j=j+1;
%     end
%     el5=summed([5]);
%     el5s=[el5s el5]; %This builds into an array that is plotted as a 
%     %histogram and also sampled for the third plot
%     
%     integ=integrate_5ms(summed)
%     integ_el5=integ([5]);
%     integ_el5s=[integ_el5s integ_el5]; %See previous comment
%     
%     i=i+1;
% end
% 
% edges=[0.5 1.5 2.5 3.5 4.5 5.5 6.5 7.5 8.5 9.5];
% 
% % subplot(2,24,[25 26 27 28 29 30]);
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% subplot(7,24,[73 74 75 76 77 78 97 98 99 100 101 102 121 122 123 124 125 126 145 146 147 148 149 150]);
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% histogram(el5s,edges,'facecolor',[0 .45 .75],'facealpha',.3)
% ylim([0 45])% check ylim matches panel 3!!!!!!!!!!!!!
% xlabel('no. input spikes');ylabel('nuclear cells');title('PC-NC');
% 
% hold on 
% histogram(integ_el5s,edges,'facecolor',[1 0 0],'facealpha',.2)
% 
% %PANEL E
% 
% %PC-CONTROLLED INTRA-GROUP EXCITATORY INPUT TO NUCLEAR CELLS HAS AN EFFECT 
% %WITH A VERY NARROW RANGE OF VARIATION BY CHANCE WHICH IS THEREFORE BOTH AT
% %ANY MOMENT THE SAME FOR ALL NUCLEAR CELLS IN A GROUP AND HIGHLY 
% %REPRODUCIBLE. WITH AND WITHOUT INTEGRATION.
% 
% % subplot(2,24,[43 44 45 46 47 48])
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% subplot(7,24,[91 92 93 94 95 96 115 116 117 118 119 120 139 140 141 142 143 144 163 164 165 166 167 168])
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% n=1;
% AAA=[]; BBB=[];
% 
% while n<6
% 
%     i=1;
%     AA=[]; BB=[];
% 
%     while i<51
%         A=randsample(el5s,10); %Randomly samples el5s, sample size 10
%         AA=[AA; A]; %Builds into a matrix of 50x10 random samples of el5s, each
%         %representing a nuclear cell
%         B=randsample(integ_el5s,10); 
%         BB=[BB; B]; 
%         i=i+1;
%     end
% 
%     AA=mean(AA,2)'; %Averages each row of the matrix AA and flips to an array of
%     %50 elements, representing the sample mean for each of 50 nuclear cells
%     BB=mean(BB,2)';
%     AAA=[AAA; AA];%Builds into a matrix of nx50 sample means, representing n
%     %examples of AA - AAA and BBB were originally used in an extra panel
%     %(the commented code at the end of this file) which was not included in
%     %the final figure. Both they, and the outer loop used to generate them,
%     %are therefore redundant.
%     BBB=[BBB; BB];
%         
%     n=n+1
% end
% 
% histogram(AA,edges,'facecolor',[0 .45 .75],'facealpha',.3)
% xlabel('excitatory input');ylabel('nuclear cells');title('Nucleo-nuclear');ylim([0 45]);
% hold on
% histogram(BB,edges,'facecolor',[1 0 0],'facealpha',.2)
% 
% %PANEL D
% 
% % PROBABILITY DISTRIBUTIONS FOR THE NUMBER OF PC SPIKES RECEIVED BY A
% % NUCLEAR CELL IN 1 ms AT AN EXTRAPOLATED PC RATE OF 147.5 HZ, WITH AND
% % WITHOUT (5 ms) INTEGRATION. THE DISTRIBUTIONS ARE BOTH NORMAL, WITH THE
% % SAME MEAN. INTEGRATION NARROWS THE DISTRIBUTION (THE PEAK IS THINNER
% % AND TALLER), REPRESENTING LOW VARIATION ACROSS A NUCLEAR GROUP AND HIGH 
% % REPODUCIBILITY
% 
% k=1;
% bigger=[];
% better=[];
% 
% while k<101
%     i=1;
%     el5s=[];
%     integ_el5s=[];
%     while i<51
%         j=1;
%         summed=zeros([1 200]);
%         while j<41
%             PC=array();
%             summed=(summed+PC);
%             j=j+1;
%         end
%         el5=summed([5]);
%         el5s=[el5s el5]; %An array of 50 elements, each representing the 
%         %number of PC spikes received by each of 50 nuclear cells in 1 ms, 
%         %without integration
%         
%         integ=integrate_5ms(summed)
%         integ_el5=integ([5]);
%         integ_el5s=[integ_el5s integ_el5]; %An array of 50 elements, each
%         %representing the number of PC spikes received by each of 50 nuclear 
%         %cells in 1 ms, with integration
% 
%         i=i+1;
%     end
%     k=k+1;
%     edges=[-0.5 0.5 1.5 2.5 3.5 4.5 5.5 6.5 7.5 8.5 9.5 10.5 11.5 12.5 13.5 14.5];
%     [N,edges]=histcounts(el5s, edges);
%     bigger=[bigger; N]; % A k x 15 matrix. Each row represents the frequency 
%     % distribution for the number of spikes received by nuclear cells in a
%     % ms, without integration
%     [N,edges]=histcounts(integ_el5s, edges);
%     better=[better; N]; % Ditto, but with integration
% 
%     % bigger=[bigger; el5s]; % A k x 50 matrix
%     % better=[better; integ_el5s]; % A k x 50 matrix
% end
% 
% % subplot(2,24,[33 34 35 36 37 38 39 40])
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% subplot(7,24,[81 82 83 84 85 86 87 88 105 106 107 108 109 110 111 112 129 130 131 132 133 134 135 136 153 154 155 156 157 158 159 160])
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% bigger=mean(bigger); % the mean of k frequency distributions (averages columns of the matrix bigger) 
% z=sum(bigger); y=bigger/z; % convert into probabilities
% x=[1:1:numel(y)];
% plot(x,y,'-o','MarkerSize',3.5,'MarkerFaceColor',[0 .35 .65],'MarkerEdgeColor',[0 .35 .65]);
% xlabel('no. input spikes');ylabel('probability');title('PC-NC');
% 
% hold on
% 
% better=mean(better);
% z=sum(better);
% y=better/z;
% x=[1:1:numel(y)];
% plot(x,y,'-o','MarkerSize',3.5,'MarkerFaceColor',[.55 0 0],'MarkerEdgeColor',[.55 0 0]);
% 
% % % [N,edges]=histcounts(bigger);
% % % z = sum(N);
% % % y = N/z;
% % % x = [1:1:numel(y)];
% % % bar(x,y,'BarWidth',1,'facecolor',[1 0 0],'facealpha',.2)
% % % xlabel('spikes/ms');ylabel('probability');title('Monosynaptic');
% % % xlim([0 15]);
% % % 
% % % % The next 3 lines remove every other x tick label
% % % ax = gca; labels = string(ax.XAxis.TickLabels); % extract
% % % labels(1:2:end) = nan; % remove every other one
% % % ax.XAxis.TickLabels = labels; % set
% % % 
% % % hold on 
% % % 
% % % [N,edges]=histcounts(better,edges);
% % % z = sum(N);
% % % y = N/z; 
% % % x = [1:1:numel(y)];
% % % bar(x,y,'BarWidth',1,'facecolor',[0 .45 .75],'facealpha',.3)
% 
